/*
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 3 of
 *  the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details:
 *
 *  http://www.gnu.org/copyleft/gpl.txt
 */

#ifndef SOUND_H
#define SOUND_H 1

#include <alsa/asoundlib.h>
#include "common.h"
#include "dft.h"

#define READI_FRAMES	512	 /* Number of frames to read from dsp */
#define PERIOD_SIZE		4096 /* Period size of dsp in frames */
#define NUM_PERIODS		4	 /* Number of periods */
#define EXACT_VAL		0	 /* Set excat value of hwparams */

#endif

